@@ -81,27 +81,86 @@ class MP_Articut:
     def __str__(self):
         return "Articut Multiprocessing API"
 
-    def parse(self, inputSTR, level="lv2", userDefinedDICT={}, chemicalBOOL=True, openDataPlaceBOOL=False, wikiDataBOOL=False, indexWithPOS=False, timeRef=None, pinyin="BOPOMOFO"):
-            payload = {"input_str": inputSTR,
-                       "level": level,
-                       "chemical": chemicalBOOL,
-                       "opendata_place": openDataPlaceBOOL,
-                       "wikidata": wikiDataBOOL,
-                       "index_with_pos": indexWithPOS,
-                       "pinyin": pinyin}
-            if userDefinedDICT:
-                payload["user_defined_dict_file"] = userDefinedDICT
-            else:
-                payload["user_defined_dict_file"] = self.userDefinedDICT
+    def parse(self, inputSTR, level="lv2", userDefinedDICT={}, chemicalBOOL=True, openDataPlaceBOOL=False, wikiDataBOOL=False, indexWithPOS=False, timeRef=None, pinyin="BOPOMOFO", autoBreakBOOL=True):
+        payload = {"level": level,
+                   "chemical": chemicalBOOL,
+                   "opendata_place": openDataPlaceBOOL,
+                   "wikidata": wikiDataBOOL,
+                   "index_with_pos": indexWithPOS,
+                   "pinyin": pinyin}
+        if userDefinedDICT:
+            payload["user_defined_dict_file"] = userDefinedDICT
+        else:
+            payload["user_defined_dict_file"] = self.userDefinedDICT
 
-            if timeRef:
-                payload["time_ref"] = str(timeRef)
+        if timeRef:
+            payload["time_ref"] = str(timeRef)
 
+        if autoBreakBOOL:
+            inputLIST = self._getInputLIST(inputSTR)
+        else:
+            inputLIST = [inputSTR]
+
+        resultDICT = {}
+        count = 0
+        for x in inputLIST:
+            payload["input_str"] = x
             response = requests.post("{}/Articut/API/".format(self.url), json=payload)
-            print(response)
             if response.status_code == 200:
-                #pprint(response.json())
-                return response.json()
+                result = response.json()
+                if not result["status"]:
+                    return result
+
+                if resultDICT:
+                    resultDICT["exec_time"] += result["exec_time"]
+                    if level in ("lv1", "lv2"):
+                        resultDICT["result_obj"].extend(result["result_obj"])
+                        resultDICT["result_pos"].extend(result["result_pos"])
+                        resultDICT["result_segmentation"].extend(result["result_segmentation"])
+                    else:
+                        resultDICT["input"].extend([[i[0] + count, i[1] + count] for i in result["input"]])
+                        resultDICT["entity"].extend(result["entity"])
+                        resultDICT["event"].extend(result["event"])
+                        resultDICT["person"].extend(result["person"])
+                        resultDICT["site"].extend(result["site"])
+                        resultDICT["time"].extend(result["time"])
+                        resultDICT["user_defined"].extend(result["user_defined"])
+                        resultDICT["utterance"].extend(result["utterance"])
+                        resultDICT["number"] = {**resultDICT["number"], **result["number"]}
+                        resultDICT["unit"] = {**resultDICT["unit"], **result["unit"]}
+                else:
+                    resultDICT = result
+                count += len(x)
+            else:
+                return response
+
+        return resultDICT
+
+    def _getInputLIST(self, inputSTR):
+        '''
+        取得長度不大於 MAX_LEN 的 input 列表
+        '''
+        MAX_LEN = 5000
+        BREAK_LIST = ["。", "？", "！", "?", "!", "\n"]
+
+        inputLIST = []
+        while True:
+            if len(inputSTR) > MAX_LEN:
+                tempSTR = inputSTR[:MAX_LEN]
+                index = 0
+                for x in BREAK_LIST:
+                    lastIndex = tempSTR.rfind(x) + 1
+                    if lastIndex > index:
+                        index = lastIndex
+                if index == 0:
+                    index = MAX_LEN
+                inputLIST.append(inputSTR[:index])
+                inputSTR = inputSTR[index:]
+            else:
+                inputLIST.append(inputSTR)
+                break
+
+        return inputLIST
 
     def bulk_parse(self, inputLIST, level="lv2", userDefinedDICT={}, chemicalBOOL=True, openDataPlaceBOOL=False, wikiDataBOOL=False, indexWithPOS=False, timeRef=None, pinyin="BOPOMOFO"):
         inputLIST2 = []
